==> quanyi-center-api-1.0.69-merge-20240527.060319-14-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/activity/RemoteActivityPrizeService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.activity;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.activity.ActivityPrizeDto;
import cn.com.duiba.quanyi.center.api.param.activity.ActivityPrizeQueryParam;

import java.util.List;
import java.util.Set;

/**
 * 活动奖品表
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@AdvancedFeignClient
public interface RemoteActivityPrizeService {
    /**
     * 新增
     *
     * @param activityPrizeDto 活动奖品
     * @return 执行结果
     */
    Long add(ActivityPrizeDto activityPrizeDto);


    /**
     * 根据主键查询
     *
     * @param id 主键
     * @return 活动奖品
     */
    ActivityPrizeDto selectById(Long id);

    /**
     * 根据主键批量查询
     *
     * @param ids 主键集合
     * @return 活动奖品列表
     */
    List<ActivityPrizeDto> selectByIds(Set<Long> ids);

    /**
     * 根据主键批量查询(包含已删除的)
     *
     * @param ids 主键集合
     * @return 活动奖品列表
     */
    List<ActivityPrizeDto> selectByIdsContainDelete(Set<Long> ids);

    /**
     * 更新
     *
     * @param activityPrizeDto 活动奖品
     * @return 执行结果
     */
    int update(ActivityPrizeDto activityPrizeDto);

    /**
     * 物理删除
     *
     * @param id 主键
     * @return 执行结果
     */
    int delete(Long id);

    /**
     * 根据活动id查询奖品列表
     *
     * @param activityId 活动id
     * @return 活动奖品
     */
    List<ActivityPrizeDto> selectByActivityId(Long activityId);

    /**
     * 根据活动id批量查询奖品列表
     *
     * @param activityIds 活动id
     * @return 活动奖品
     */
    List<ActivityPrizeDto> selectByActivityIds(Set<Long> activityIds);

    /**
     * 分页查询
     *
     * @param param param
     * @return 活动
     */
    List<ActivityPrizeDto> selectPage(ActivityPrizeQueryParam param);

    /**
     * count
     *
     * @param param param
     * @return {@link Integer}
     */
    Integer count(ActivityPrizeQueryParam param);

}

==> quanyi-center-api-1.1.44-merge-20240821.060450-48-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/activity/RemoteActivityPrizeService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.activity;


import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.activity.ActivityPrizeDto;
import cn.com.duiba.quanyi.center.api.param.activity.ActivityPrizeQueryParam;

import java.util.List;
import java.util.Set;

/**
 * 活动奖品表
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@AdvancedFeignClient
public interface RemoteActivityPrizeService {
    /**
     * 新增
     *
     * @param activityPrizeDto 活动奖品
     * @return 执行结果
     */
    Long add(ActivityPrizeDto activityPrizeDto);

    /**
     * 根据活动id和spu类型查询
     *
     * @param activityId 活动id
     * @param spuType    spu类型
     * @return 活动奖品
     */
    List<ActivityPrizeDto> selectByActivityIdAndSpuType(Long activityId, Integer spuType);


    /**
     * 根据主键查询
     *
     * @param id 主键
     * @return 活动奖品
     */
    ActivityPrizeDto selectById(Long id);

    /**
     * 根据主键批量查询
     *
     * @param ids 主键集合
     * @return 活动奖品列表
     */
    List<ActivityPrizeDto> selectByIds(Set<Long> ids);

    /**
     * 根据主键批量查询(包含已删除的)
     *
     * @param ids 主键集合
     * @return 活动奖品列表
     */
    List<ActivityPrizeDto> selectByIdsContainDelete(Set<Long> ids);

    /**
     * 更新
     *
     * @param activityPrizeDto 活动奖品
     * @return 执行结果
     */
    int update(ActivityPrizeDto activityPrizeDto);

    /**
     * 物理删除
     *
     * @param id 主键
     * @return 执行结果
     */
    int delete(Long id);

    /**
     * 根据活动id查询奖品列表
     *
     * @param activityId 活动id
     * @return 活动奖品
     */
    List<ActivityPrizeDto> selectByActivityId(Long activityId);

    /**
     * 根据活动id批量查询奖品列表
     *
     * @param activityIds 活动id
     * @return 活动奖品
     */
    List<ActivityPrizeDto> selectByActivityIds(Set<Long> activityIds);

    /**
     * 分页查询（必须使用 activity_id 过滤，防止后续模糊匹配时 SQL 超时）
     *
     * @param param param
     * @return 活动
     */
    List<ActivityPrizeDto> selectPageByPrizeName(ActivityPrizeQueryParam param);

    /**
     * count（必须使用 activity_id 过滤，防止后续模糊匹配时 SQL 超时）
     *
     * @param param param
     * @return {@link Integer}
     */
    Integer countByPrizeName(ActivityPrizeQueryParam param);

    /**
     * 插入总库存
     *
     * @param prizeId 奖品id
     * @param totalNum 总库存
     * @return 是否成功
     */
    boolean insertTotalNum(Long prizeId, Long totalNum);

    /**
     * 更新总库存
     *
     * @param id 主键id
     * @param totalNum 总库存
     * @return 更新结果
     */
    boolean updateTotalNum(Long id, Long totalNum);

}
